@@ -1,24 +1,51 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
-/**
- * file upload functions
- *
- * @package PhpMyAdmin
- */
+
+declare(strict_types=1);
+
 namespace PhpMyAdmin;
 
-use PhpMyAdmin\Core;
-use PhpMyAdmin\Message;
-use PhpMyAdmin\Util;
-use PhpMyAdmin\ZipExtension;
+use ZipArchive;
+use const UPLOAD_ERR_CANT_WRITE;
+use const UPLOAD_ERR_EXTENSION;
+use const UPLOAD_ERR_FORM_SIZE;
+use const UPLOAD_ERR_INI_SIZE;
+use const UPLOAD_ERR_NO_FILE;
+use const UPLOAD_ERR_NO_TMP_DIR;
+use const UPLOAD_ERR_OK;
+use const UPLOAD_ERR_PARTIAL;
+use function basename;
+use function bin2hex;
+use function bzopen;
+use function bzread;
+use function extension_loaded;
+use function fclose;
+use function feof;
+use function file_get_contents;
+use function filesize;
+use function fopen;
+use function fread;
+use function function_exists;
+use function gzopen;
+use function gzread;
+use function is_link;
+use function is_readable;
+use function is_string;
+use function is_uploaded_file;
+use function mb_strcut;
+use function move_uploaded_file;
+use function ob_end_clean;
+use function ob_start;
+use function sprintf;
+use function strlen;
+use function tempnam;
+use function trim;
+use function unlink;
 
 /**
  * File wrapper class
  *
  * @todo when uploading a file into a blob field, should we also consider using
  *       chunks like in import? UPDATE `table` SET `field` = `field` + [chunk]
- *
- * @package PhpMyAdmin
  */
 class File
 {
@@ -26,66 +53,52 @@ class File
      * @var string the temporary file name
      * @access protected
      */
-    var $_name = null;
+    protected $name = null;
 
     /**
      * @var string the content
      * @access protected
      */
-    var $_content = null;
+    protected $content = null;
 
     /**
      * @var Message|null the error message
      * @access protected
      */
-    var $_error_message = null;
+    protected $errorMessage = null;
 
     /**
      * @var bool whether the file is temporary or not
      * @access protected
      */
-    var $_is_temp = false;
+    protected $isTemp = false;
 
     /**
      * @var string type of compression
      * @access protected
      */
-    var $_compression = null;
+    protected $compression = null;
 
-    /**
-     * @var integer
-     */
-    var $_offset = 0;
+    /** @var int */
+    protected $offset = 0;
 
-    /**
-     * @var integer size of chunk to read with every step
-     */
-    var $_chunk_size = 32768;
+    /** @var int size of chunk to read with every step */
+    protected $chunkSize = 32768;
 
-    /**
-     * @var resource file handle
-     */
-    var $_handle = null;
+    /** @var resource|null file handle */
+    protected $handle = null;
 
-    /**
-     * @var boolean whether to decompress content before returning
-     */
-    var $_decompress = false;
+    /** @var bool whether to decompress content before returning */
+    protected $decompress = false;
 
-    /**
-     * @var string charset of file
-     */
-    var $_charset = null;
+    /** @var string charset of file */
+    protected $charset = null;
 
-    /**
-     * @var ZipExtension
-     */
+    /** @var ZipExtension */
     private $zipExtension;
 
     /**
-     * constructor
-     *
-     * @param boolean|string $name file name or false
+     * @param bool|string $name file name or false
      *
      * @access public
      */
@@ -95,16 +108,19 @@ class File
             $this->setName($name);
         }
 
-        if (extension_loaded('zip')) {
-            $this->zipExtension = new ZipExtension();
+        if (! extension_loaded('zip')) {
+            return;
         }
+
+        $this->zipExtension = new ZipExtension(new ZipArchive());
     }
 
     /**
      * destructor
      *
      * @see     File::cleanUp()
-     * @access  public
+     *
+     * @access public
      */
     public function __destruct()
     {
@@ -114,10 +130,11 @@ class File
     /**
      * deletes file if it is temporary, usually from a moved upload file
      *
-     * @access  public
-     * @return boolean success
+     * @return bool success
+     *
+     * @access public
      */
-    public function cleanUp()
+    public function cleanUp(): bool
     {
         if ($this->isTemp()) {
             return $this->delete();
@@ -129,74 +146,82 @@ class File
     /**
      * deletes the file
      *
-     * @access  public
-     * @return boolean success
+     * @return bool success
+     *
+     * @access public
      */
-    public function delete()
+    public function delete(): bool
     {
-        return unlink($this->getName());
+        return unlink((string) $this->getName());
     }
 
     /**
      * checks or sets the temp flag for this file
      * file objects with temp flags are deleted with object destruction
      *
-     * @param boolean $is_temp sets the temp flag
+     * @param bool $is_temp sets the temp flag
      *
-     * @return boolean File::$_is_temp
-     * @access  public
+     * @return bool File::$_is_temp
+     *
+     * @access public
      */
-    public function isTemp($is_temp = null)
+    public function isTemp(?bool $is_temp = null): bool
     {
-        if (null !== $is_temp) {
-            $this->_is_temp = (bool) $is_temp;
+        if ($is_temp !== null) {
+            $this->isTemp = $is_temp;
         }
 
-        return $this->_is_temp;
+        return $this->isTemp;
     }
 
     /**
      * accessor
      *
-     * @param string $name file name
+     * @param string|null $name file name
      *
-     * @return void
-     * @access  public
+     * @access public
      */
-    public function setName($name)
+    public function setName(?string $name): void
     {
-        $this->_name = trim($name);
+        $this->name = trim((string) $name);
     }
 
     /**
      * Gets file content
      *
-     * @return string|false the binary file content,
-     *                      or false if no content
+     * @return string|false|null the binary file content, or false if no content
      *
-     * @access  public
+     * @access public
      */
     public function getRawContent()
     {
-        if (null === $this->_content) {
-            if ($this->isUploaded() && ! $this->checkUploadedFile()) {
-                return false;
-            }
-
-            if (! $this->isReadable()) {
-                return false;
-            }
-
-            if (function_exists('file_get_contents')) {
-                $this->_content = file_get_contents($this->getName());
-            } elseif ($size = filesize($this->getName())) {
-                $handle = fopen($this->getName(), 'rb');
-                $this->_content = fread($handle, $size);
-                fclose($handle);
-            }
+        if ($this->content !== null) {
+            return $this->content;
         }
 
-        return $this->_content;
+        if ($this->isUploaded() && ! $this->checkUploadedFile()) {
+            return false;
+        }
+
+        if (! $this->isReadable()) {
+            return false;
+        }
+
+        if (function_exists('file_get_contents')) {
+            $this->content = file_get_contents((string) $this->getName());
+
+            return $this->content;
+        }
+
+        $size = filesize((string) $this->getName());
+
+        if ($size) {
+            $handle = fopen((string) $this->getName(), 'rb');
+            $this->content = fread($handle, $size);
+            fclose($handle);
+        }
+
+        return $this->content;
     }
 
     /**
@@ -205,42 +230,42 @@ class File
      * @return string|false the binary file content as a string,
      *                      or false if no content
      *
-     * @access  public
+     * @access public
      */
     public function getContent()
     {
         $result = $this->getRawContent();
-        if ($result === false) {
+        if ($result === false || $result === null) {
             return false;
         }
+
         return '0x' . bin2hex($result);
     }
 
     /**
      * Whether file is uploaded.
      *
-     * @access  public
-     *
-     * @return bool
+     * @access public
      */
-    public function isUploaded()
+    public function isUploaded(): bool
     {
-        if (! is_string($this->getName())) {
+        if ($this->getName() === null) {
             return false;
-        } else {
-            return is_uploaded_file($this->getName());
         }
+
+        return is_uploaded_file($this->getName());
     }
 
     /**
      * accessor
      *
-     * @access  public
-     * @return string  File::$_name
+     * @return string|null File::$_name
+     *
+     * @access public
      */
-    public function getName()
+    public function getName(): ?string
     {
-        return $this->_name;
+        return $this->name;
     }
 
     /**
@@ -248,16 +273,18 @@ class File
      *
      * @param string $name name of file uploaded
      *
-     * @return boolean success
-     * @access  public
+     * @return bool success
+     *
+     * @access public
      */
-    public function setUploadedFile($name)
+    public function setUploadedFile(string $name): bool
     {
         $this->setName($name);
 
         if (! $this->isUploaded()) {
             $this->setName(null);
-            $this->_error_message = Message::error(__('File was not an uploaded file.'));
+            $this->errorMessage = Message::error(__('File was not an uploaded file.'));
+
             return false;
         }
 
@@ -270,60 +297,59 @@ class File
      * @param string $key       the md5 hash of the column name
      * @param string $rownumber number of row to process
      *
-     * @return boolean success
-     * @access  public
+     * @return bool success
+     *
+     * @access public
      */
-    public function setUploadedFromTblChangeRequest($key, $rownumber)
-    {
+    public function setUploadedFromTblChangeRequest(
+        string $key,
+        string $rownumber
+    ): bool {
         if (! isset($_FILES['fields_upload'])
             || empty($_FILES['fields_upload']['name']['multi_edit'][$rownumber][$key])
         ) {
             return false;
         }
-        $file = File::fetchUploadedFromTblChangeRequestMultiple(
+        $file = $this->fetchUploadedFromTblChangeRequestMultiple(
             $_FILES['fields_upload'],
             $rownumber,
             $key
         );
 
-        // check for file upload errors
         switch ($file['error']) {
-        // we do not use the PHP constants here cause not all constants
-        // are defined in all versions of PHP - but the correct constants names
-        // are given as comment
-        case 0: //UPLOAD_ERR_OK:
-            return $this->setUploadedFile($file['tmp_name']);
-        case 4: //UPLOAD_ERR_NO_FILE:
-            break;
-        case 1: //UPLOAD_ERR_INI_SIZE:
-            $this->_error_message = Message::error(__(
-                'The uploaded file exceeds the upload_max_filesize directive in '
-                . 'php.ini.'
-            ));
-            break;
-        case 2: //UPLOAD_ERR_FORM_SIZE:
-            $this->_error_message = Message::error(__(
-                'The uploaded file exceeds the MAX_FILE_SIZE directive that was '
-                . 'specified in the HTML form.'
-            ));
-            break;
-        case 3: //UPLOAD_ERR_PARTIAL:
-            $this->_error_message = Message::error(__(
-                'The uploaded file was only partially uploaded.'
-            ));
-            break;
-        case 6: //UPLOAD_ERR_NO_TMP_DIR:
-            $this->_error_message = Message::error(__('Missing a temporary folder.'));
-            break;
-        case 7: //UPLOAD_ERR_CANT_WRITE:
-            $this->_error_message = Message::error(__('Failed to write file to disk.'));
-            break;
-        case 8: //UPLOAD_ERR_EXTENSION:
-            $this->_error_message = Message::error(__('File upload stopped by extension.'));
-            break;
-        default:
-            $this->_error_message = Message::error(__('Unknown error in file upload.'));
-        } // end switch
+            case UPLOAD_ERR_OK:
+                return $this->setUploadedFile($file['tmp_name']);
+            case UPLOAD_ERR_NO_FILE:
+                break;
+            case UPLOAD_ERR_INI_SIZE:
+                $this->errorMessage = Message::error(__(
+                    'The uploaded file exceeds the upload_max_filesize directive in '
+                    . 'php.ini.'
+                ));
+                break;
+            case UPLOAD_ERR_FORM_SIZE:
+                $this->errorMessage = Message::error(__(
+                    'The uploaded file exceeds the MAX_FILE_SIZE directive that was '
+                    . 'specified in the HTML form.'
+                ));
+                break;
+            case UPLOAD_ERR_PARTIAL:
+                $this->errorMessage = Message::error(__(
+                    'The uploaded file was only partially uploaded.'
+                ));
+                break;
+            case UPLOAD_ERR_NO_TMP_DIR:
+                $this->errorMessage = Message::error(__('Missing a temporary folder.'));
+                break;
+            case UPLOAD_ERR_CANT_WRITE:
+                $this->errorMessage = Message::error(__('Failed to write file to disk.'));
+                break;
+            case UPLOAD_ERR_EXTENSION:
+                $this->errorMessage = Message::error(__('File upload stopped by extension.'));
+                break;
+            default:
+                $this->errorMessage = Message::error(__('Unknown error in file upload.'));
+        }
 
         return false;
     }
@@ -352,21 +378,22 @@ class File
      * @param string $key       key to process
      *
      * @return array
-     * @access  public
+     *
+     * @access public
      * @static
      */
     public function fetchUploadedFromTblChangeRequestMultiple(
-        array $file, $rownumber, $key
-    ) {
-        $new_file = array(
+        array $file,
+        string $rownumber,
+        string $key
+    ): array {
+        return [
             'name' => $file['name']['multi_edit'][$rownumber][$key],
             'type' => $file['type']['multi_edit'][$rownumber][$key],
             'size' => $file['size']['multi_edit'][$rownumber][$key],
             'tmp_name' => $file['tmp_name']['multi_edit'][$rownumber][$key],
             'error' => $file['error']['multi_edit'][$rownumber][$key],
-        );
-
-        return $new_file;
+        ];
     }
 
     /**
@@ -375,11 +402,14 @@ class File
      * @param string $key       the md5 hash of the column name
      * @param string $rownumber number of row to process
      *
-     * @return boolean success
-     * @access  public
+     * @return bool success
+     *
+     * @access public
      */
-    public function setSelectedFromTblChangeRequest($key, $rownumber = null)
-    {
+    public function setSelectedFromTblChangeRequest(
+        string $key,
+        ?string $rownumber = null
+    ): bool {
         if (! empty($_REQUEST['fields_uploadlocal']['multi_edit'][$rownumber][$key])
             && is_string($_REQUEST['fields_uploadlocal']['multi_edit'][$rownumber][$key])
         ) {
@@ -395,23 +425,25 @@ class File
     /**
      * Returns possible error message.
      *
-     * @access  public
      * @return Message|null error message
+     *
+     * @access public
      */
-    public function getError()
+    public function getError(): ?Message
     {
-        return $this->_error_message;
+        return $this->errorMessage;
     }
 
     /**
      * Checks whether there was any error.
      *
-     * @access  public
-     * @return boolean whether an error occurred or not
+     * @return bool whether an error occurred or not
+     *
+     * @access public
      */
-    public function isError()
+    public function isError(): bool
     {
-        return ! is_null($this->_error_message);
+        return $this->errorMessage !== null;
     }
 
     /**
@@ -421,18 +453,23 @@ class File
      * @param string $key       the md5 hash of the column name
      * @param string $rownumber number of row to process
      *
-     * @return boolean success
-     * @access  public
+     * @return bool success
+     *
+     * @access public
      */
-    public function checkTblChangeForm($key, $rownumber)
+    public function checkTblChangeForm(string $key, string $rownumber): bool
     {
         if ($this->setUploadedFromTblChangeRequest($key, $rownumber)) {
             // well done ...
-            $this->_error_message = null;
+            $this->errorMessage = null;
+
             return true;
-        } elseif ($this->setSelectedFromTblChangeRequest($key, $rownumber)) {
+        }
+
+        if ($this->setSelectedFromTblChangeRequest($key, $rownumber)) {
             // well done ...
-            $this->_error_message = null;
+            $this->errorMessage = null;
+
             return true;
         }
         // all failed, whether just no file uploaded/selected or an error
@@ -445,26 +482,33 @@ class File
      *
      * @param string $name file name
      *
-     * @return boolean success
-     * @access  public
+     * @return bool success
+     *
+     * @access public
      */
-    public function setLocalSelectedFile($name)
+    public function setLocalSelectedFile(string $name): bool
     {
         if (empty($GLOBALS['cfg']['UploadDir'])) {
             return false;
         }
 
+        if (! is_string($GLOBALS['cfg']['UploadDir'])) {
+            return false;
+        }
+
         $this->setName(
             Util::userDir($GLOBALS['cfg']['UploadDir']) . Core::securePath($name)
         );
-        if (@is_link($this->getName())) {
-            $this->_error_message = __('File is a symbolic link');
+        if (@is_link((string) $this->getName())) {
+            $this->errorMessage = Message::error(__('File is a symbolic link'));
             $this->setName(null);
+
             return false;
         }
         if (! $this->isReadable()) {
-            $this->_error_message = Message::error(__('File could not be read!'));
+            $this->errorMessage = Message::error(__('File could not be read!'));
             $this->setName(null);
+
             return false;
         }
 
@@ -474,14 +518,15 @@ class File
     /**
      * Checks whether file can be read.
      *
-     * @access  public
-     * @return boolean whether the file is readable or not
+     * @return bool whether the file is readable or not
+     *
+     * @access public
      */
-    public function isReadable()
+    public function isReadable(): bool
     {
         // suppress warnings from being displayed, but not from being logged
         // any file access outside of open_basedir will issue a warning
-        return @is_readable($this->getName());
+        return @is_readable((string) $this->getName());
     }
 
     /**
@@ -489,40 +534,43 @@ class File
      * before opening it. The FAQ 1.11 explains how to create the "./tmp"
      * directory - if needed
      *
+     * @return bool whether uploaded file is fine or not
+     *
      * @todo move check of $cfg['TempDir'] into Config?
-     * @access  public
-     * @return boolean whether uploaded file is fine or not
+     * @access public
      */
-    public function checkUploadedFile()
+    public function checkUploadedFile(): bool
     {
         if ($this->isReadable()) {
             return true;
         }
 
         $tmp_subdir = $GLOBALS['PMA_Config']->getUploadTempDir();
-        if (is_null($tmp_subdir)) {
+        if ($tmp_subdir === null) {
             // cannot create directory or access, point user to FAQ 1.11
-            $this->_error_message = Message::error(__(
+            $this->errorMessage = Message::error(__(
                 'Error moving the uploaded file, see [doc@faq1-11]FAQ 1.11[/doc].'
             ));
+
             return false;
         }
 
-        $new_file_to_upload = tempnam(
+        $new_file_to_upload = (string) tempnam(
             $tmp_subdir,
-            basename($this->getName())
+            basename((string) $this->getName())
         );
 
         // suppress warnings from being displayed, but not from being logged
         // any file access outside of open_basedir will issue a warning
         ob_start();
         $move_uploaded_file_result = move_uploaded_file(
-            $this->getName(),
+            (string) $this->getName(),
             $new_file_to_upload
         );
         ob_end_clean();
         if (! $move_uploaded_file_result) {
-            $this->_error_message = Message::error(__('Error while moving uploaded file.'));
+            $this->errorMessage = Message::error(__('Error while moving uploaded file.'));
+
             return false;
         }
 
@@ -530,7 +578,8 @@ class File
         $this->isTemp(true);
 
         if (! $this->isReadable()) {
-            $this->_error_message = Message::error(__('Cannot read uploaded file.'));
+            $this->errorMessage = Message::error(__('Cannot read uploaded file.'));
+
             return false;
         }
 
@@ -540,39 +589,40 @@ class File
     /**
      * Detects what compression the file uses
      *
-     * @todo    move file read part into readChunk() or getChunk()
-     * @todo    add support for compression plugins
-     * @access  protected
-     * @return  string|false false on error, otherwise string MIME type of
-     *                       compression, none for none
+     * @return string|false false on error, otherwise string MIME type of
+     *                      compression, none for none
+     *
+     * @todo   move file read part into readChunk() or getChunk()
+     * @todo   add support for compression plugins
+     * @access protected
      */
     protected function detectCompression()
     {
         // suppress warnings from being displayed, but not from being logged
         // f.e. any file access outside of open_basedir will issue a warning
         ob_start();
-        $file = fopen($this->getName(), 'rb');
+        $file = fopen((string) $this->getName(), 'rb');
         ob_end_clean();
 
         if (! $file) {
-            $this->_error_message = Message::error(__('File could not be read!'));
+            $this->errorMessage = Message::error(__('File could not be read!'));
+
             return false;
         }
 
-        $this->_compression = Util::getCompressionMimeType($file);
-        return $this->_compression;
+        $this->compression = Util::getCompressionMimeType($file);
+
+        return $this->compression;
     }
 
     /**
      * Sets whether the content should be decompressed before returned
      *
-     * @param boolean $decompress whether to decompress
-     *
-     * @return void
+     * @param bool $decompress whether to decompress
      */
-    public function setDecompressContent($decompress)
+    public function setDecompressContent(bool $decompress): void
     {
-        $this->_decompress = (bool) $decompress;
+        $this->decompress = $decompress;
     }
 
     /**
@@ -582,33 +632,29 @@ class File
      */
     public function getHandle()
     {
-        if (null === $this->_handle) {
+        if ($this->handle === null) {
             $this->open();
         }
-        return $this->_handle;
+
+        return $this->handle;
     }
 
     /**
      * Sets the file handle
      *
-     * @param object $handle file handle
-     *
-     * @return void
+     * @param resource $handle file handle
      */
-    public function setHandle($handle)
+    public function setHandle($handle): void
     {
-        $this->_handle = $handle;
+        $this->handle = $handle;
     }
 
-
     /**
      * Sets error message for unsupported compression.
-     *
-     * @return void
      */
-    public function errorUnsupported()
+    public function errorUnsupported(): void
     {
-        $this->_error_message = Message::error(sprintf(
+        $this->errorMessage = Message::error(sprintf(
             __(
                 'You attempted to load file with unsupported compression (%s). '
                 . 'Either support for it is not implemented or disabled by your '
@@ -620,97 +666,96 @@ class File
 
     /**
      * Attempts to open the file.
-     *
-     * @return bool
      */
-    public function open()
+    public function open(): bool
     {
-        if (! $this->_decompress) {
-            $this->_handle = @fopen($this->getName(), 'r');
+        if (! $this->decompress) {
+            $this->handle = @fopen((string) $this->getName(), 'r');
         }
 
         switch ($this->getCompression()) {
-        case false:
-            return false;
-        case 'application/bzip2':
-            if ($GLOBALS['cfg']['BZipDump'] && function_exists('bzopen')) {
-                $this->_handle = @bzopen($this->getName(), 'r');
-            } else {
-                $this->errorUnsupported();
+            case false:
                 return false;
-            }
-            break;
-        case 'application/gzip':
-            if ($GLOBALS['cfg']['GZipDump'] && function_exists('gzopen')) {
-                $this->_handle = @gzopen($this->getName(), 'r');
-            } else {
-                $this->errorUnsupported();
-                return false;
-            }
-            break;
-        case 'application/zip':
-            if ($GLOBALS['cfg']['ZipDump'] && function_exists('zip_open')) {
-                return $this->openZip();
-            }
+            case 'application/bzip2':
+                if (! $GLOBALS['cfg']['BZipDump'] || ! function_exists('bzopen')) {
+                    $this->errorUnsupported();
 
-            $this->errorUnsupported();
-            return false;
-        case 'none':
-            $this->_handle = @fopen($this->getName(), 'r');
-            break;
-        default:
-            $this->errorUnsupported();
-            return false;
+                    return false;
+                }
+
+                $this->handle = @bzopen($this->getName(), 'r');
+                break;
+            case 'application/gzip':
+                if (! $GLOBALS['cfg']['GZipDump'] || ! function_exists('gzopen')) {
+                    $this->errorUnsupported();
+
+                    return false;
+                }
+
+                $this->handle = @gzopen((string) $this->getName(), 'r');
+                break;
+            case 'application/zip':
+                if ($GLOBALS['cfg']['ZipDump'] && function_exists('zip_open')) {
+                    return $this->openZip();
+                }
+
+                $this->errorUnsupported();
+
+                return false;
+            case 'none':
+                $this->handle = @fopen((string) $this->getName(), 'r');
+                break;
+            default:
+                $this->errorUnsupported();
+
+                return false;
         }
 
-        return ($this->_handle !== false);
+        return $this->handle !== false;
     }
 
     /**
      * Opens file from zip
      *
      * @param string|null $specific_entry Entry to open
-     *
-     * @return bool
      */
-    public function openZip($specific_entry = null)
+    public function openZip(?string $specific_entry = null): bool
     {
         $result = $this->zipExtension->getContents($this->getName(), $specific_entry);
         if (! empty($result['error'])) {
-            $this->_error_message = Message::rawError($result['error']);
+            $this->errorMessage = Message::rawError($result['error']);
+
             return false;
         }
-        $this->_content = $result['data'];
-        $this->_offset = 0;
+        $this->content = $result['data'];
+        $this->offset = 0;
+
         return true;
     }
 
     /**
      * Checks whether we've reached end of file
-     *
-     * @return bool
      */
-    public function eof()
+    public function eof(): bool
     {
-        if (! is_null($this->_handle)) {
-            return feof($this->_handle);
+        if ($this->handle !== null) {
+            return feof($this->handle);
         }
-        return $this->_offset == strlen($this->_content);
+
+        return $this->offset == strlen($this->content);
     }
 
     /**
      * Closes the file
-     *
-     * @return void
      */
-    public function close()
+    public function close(): void
     {
-        if (! is_null($this->_handle)) {
-            fclose($this->_handle);
-            $this->_handle = null;
+        if ($this->handle !== null) {
+            fclose($this->handle);
+            $this->handle = null;
         } else {
-            $this->_content = '';
-            $this->_offset = 0;
+            $this->content = '';
+            $this->offset = 0;
         }
         $this->cleanUp();
     }
@@ -719,23 +764,22 @@ class File
      * Reads data from file
      *
      * @param int $size Number of bytes to read
-     *
-     * @return string
      */
-    public function read($size)
+    public function read(int $size): string
     {
-        switch ($this->_compression) {
-        case 'application/bzip2':
-            return bzread($this->_handle, $size);
-        case 'application/gzip':
-            return gzread($this->_handle, $size);
-        case 'application/zip':
-            $result = mb_strcut($this->_content, $this->_offset, $size);
-            $this->_offset += strlen($result);
-            return $result;
-        case 'none':
-        default:
-            return fread($this->_handle, $size);
+        switch ($this->compression) {
+            case 'application/bzip2':
+                return bzread($this->handle, $size);
+            case 'application/gzip':
+                return gzread($this->handle, $size);
+            case 'application/zip':
+                $result = mb_strcut($this->content, $this->offset, $size);
+                $this->offset += strlen($result);
+
+                return $result;
+            case 'none':
+            default:
+                return fread($this->handle, $size);
         }
     }
 
@@ -744,77 +788,74 @@ class File
      *
      * @return string character set of the file
      */
-    public function getCharset()
+    public function getCharset(): string
     {
-        return $this->_charset;
+        return $this->charset;
     }
 
     /**
      * Sets the character set of the file
      *
      * @param string $charset character set of the file
-     *
-     * @return void
      */
-    public function setCharset($charset)
+    public function setCharset(string $charset): void
     {
-        $this->_charset = $charset;
+        $this->charset = $charset;
     }
 
     /**
      * Returns compression used by file.
      *
      * @return string MIME type of compression, none for none
-     * @access  public
+     *
+     * @access public
      */
-    public function getCompression()
+    public function getCompression(): string
     {
-        if (null === $this->_compression) {
+        if ($this->compression === null) {
             return $this->detectCompression();
         }
 
-        return $this->_compression;
+        return $this->compression;
     }
 
     /**
      * Returns the offset
      *
-     * @return integer the offset
+     * @return int the offset
      */
-    public function getOffset()
+    public function getOffset(): int
     {
-        return $this->_offset;
+        return $this->offset;
     }
 
     /**
      * Returns the chunk size
      *
-     * @return integer the chunk size
+     * @return int the chunk size
      */
-    public function getChunkSize()
+    public function getChunkSize(): int
     {
-        return $this->_chunk_size;
+        return $this->chunkSize;
     }
 
     /**
      * Sets the chunk size
      *
-     * @param integer $chunk_size the chunk size
-     *
-     * @return void
+     * @param int $chunkSize the chunk size
      */
-    public function setChunkSize($chunk_size)
+    public function setChunkSize(int $chunkSize): void
     {
-        $this->_chunk_size = (int) $chunk_size;
+        $this->chunkSize = $chunkSize;
     }
 
     /**
      * Returns the length of the content in the file
      *
-     * @return integer the length of the file content
+     * @return int the length of the file content
      */
-    public function getContentLength()
+    public function getContentLength(): int
     {
-        return strlen($this->_content);
+        return strlen($this->content);
     }
 }
